/*
		GNU GENERAL PUBLIC LICENSE
		Version 3, 29 June 2007


kyoketsu, a Client-To-Client Network Enumeration System
Copyright (C) 2024 Russell Hrubesky, ChiralWorks Software LLC

 Copyright (C) 2007 Free Software Foundation, Inc. <https://fsf.org/>
 Everyone is permitted to copy and distribute verbatim copies
 of this license document, but changing it is not allowed.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License,
or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.

*/

package main

import (
	"flag"
	"fmt"
	"log"
	"net"
	"strings"
	"sync"

	kyoketsu "git.aetherial.dev/aeth/kyoketsu/pkg"
)

func main() {

	ip := flag.String("ips", "", "single ip address with CIDR notation to gather info about")
	flag.Parse()

	var err error
	var addr *kyoketsu.IpSubnetMapper
	addr, err = kyoketsu.GetNetworkAddresses(*ip)
	if err != nil {
		log.Fatal(err)
	}
	var wg sync.WaitGroup
	for i := range addr.Ipv4s {
		wg.Add(1)
		go func(target string, wg *sync.WaitGroup) {
			defer wg.Done()
			out := kyoketsu.PortWalk(target, kyoketsu.RetrieveScanDirectives().Pairs)
			if len(out.ListeningPorts) > 0 {
				dns, _ := net.LookupAddr(out.IpAddress)
				out.Fqdn = strings.Join(dns, ", ")

				fmt.Printf("%+v\n", out)

			}

		}(addr.Ipv4s[i].String(), &wg)

	}
	wg.Wait()
}
